Struct diem_crypto::x25519::PublicKey [−][src]
pub struct PublicKey(_);Expand description
This type should be used to deserialize a received public key
Implementations
Deserialize an X25119 PublicKey from its representation as an Ed25519PublicKey, following the XEdDSA approach. This is meant to compensate for the poor key storage capabilities of key management solutions, and NOT to promote double usage of keys under several schemes, which would lead to BAD vulnerabilities.